@@ -1,7 +1,7 @@
 #--
 # This file is part of Sonic Pi: http://sonic-pi.net
 # Full project source: https://github.com/samaaron/sonic-pi
-# License: https://github.com/samaaron/sonic-pi/blob/master/LICENSE.md
+# License: https://github.com/samaaron/sonic-pi/blob/main/LICENSE.md
 #
 # Copyright 2013, 2014, 2015, 2016 by Sam Aaron (http://sam.aaron.name).
 # All rights reserved.
@@ -18,8 +18,8 @@ module SonicPi
   class OSCTester < Minitest::Test
 
     def test_basic_address_encoding
-      encoder = FastOsc
-      decoder = FastOsc
+      decoder = ::SonicPi::OSC::OscDecode.new(true)
+      encoder = ::SonicPi::OSC::OscEncode.new(true)
 
       address = "/foo"
 
@@ -31,8 +31,8 @@ module SonicPi
 
 
     def test_args_encoding_multiple
-      encoder = FastOsc
-      decoder = FastOsc
+      decoder = ::SonicPi::OSC::OscDecode.new(true)
+      encoder = ::SonicPi::OSC::OscEncode.new(true)
 
       address = "/feooblah"
 
